"""Juju controller charm.

The only function of this charm at this stage is deploying nrpe checks and
allowing subordinates to be installed.
"""
import os

from charmhelpers.contrib.charmsupport import nrpe
from charmhelpers.core import hookenv

from charms.reactive import (
    clear_flag,
    hook,
    set_flag,
    when,
    when_file_changed,
    when_not,
)

from lib_juju_controller import JujuControllerHelper

helper = JujuControllerHelper()

PLUGINS_DIR = "/usr/local/lib/nagios/plugins/"


@when_not("juju-controller.installed")
def install_juju_controller():
    """Install the juju controller charm. This is a no-op for now."""
    # Do your setup here.
    #
    # If your charm has other dependencies before it can install,
    # add those as @when() clauses above., or as additional @when()
    # decorated handlers below
    #
    # See the following for information about reactive charms:
    #
    #  * https://jujucharms.com/docs/devel/developer-getting-started
    #  * https://github.com/juju-solutions/layer-basic#overview
    #
    set_flag("juju-controller.installed")
    hookenv.status_set("active", "Ready")


@when("nrpe-external-master.available")
@when("nrpe-plugins.installed")
def update_nrpe_config():
    """Configure nrpe checks."""
    hostname = nrpe.get_nagios_hostname()
    current_unit = nrpe.get_nagios_unit_name()
    nrpe_setup = nrpe.NRPE(hostname=hostname)

    # Service checks
    nrpe.add_init_service_checks(nrpe_setup, helper.services, current_unit)

    # Health endpoint
    nrpe_setup.add_check(
        shortname="juju_health",
        description="Juju health check for the built-in health endpoint",
        check_cmd=os.path.join(PLUGINS_DIR, "check_jujucontroller.py"),
    )
    # cache agent.conf data (required by the endpoint check)
    cache_agent_conf()

    nrpe_setup.write()
    hookenv.status_set("active", "NRPE configured")


@when_not("nrpe-plugins.installed")
def update_plugins():
    """Copy nrpe plugins to the system path."""
    src_dir = os.path.join(hookenv.charm_dir(), "files", "plugins/")
    nrpe.copy_nrpe_checks(src_dir)
    set_flag("nrpe-plugins.installed")


@when_file_changed(helper.agent_conf_path)
@when("nrpe-external-master.available")
def cache_agent_conf():
    """Cache parts of agent.conf in a file the nagios user can read."""
    helper.dump_ca()
    helper.dump_public_agent_conf()


@hook("upgrade-charm")
def upgrade_charm():
    """Unset all custom flags to prepare for charm upgrade."""
    clear_flag("nrpe-plugins.installed")
    clear_flag("juju-controller.installed")
